X-IPE Architecture Diagram

🎨
Presentation Layer UI & VIEWS
Templates
index.html settings.html base.html
Frontend Modules
WorkplaceManager Terminal StageToolbox ContentRenderer EventBus
⚙️
Business Logic Layer SERVICES
Core Services
FileService IdeasService TerminalService
Config Services
ConfigService SettingsService ToolsConfigService
Extension Services
ThemesService SkillsService
💾
Data Layer STORAGE
Project Files
📁 docs/ 📁 src/ 📁 static/
Configuration
📄 tools.json 📄 .x-ipe.yaml
Session Data
📁 instance/